﻿using System;
using System.Windows;
using System.Windows.Media.Animation;
using System.Windows.Media.Imaging;

//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
//====================================================

namespace WpfTextWindows
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        readonly int numberFrames = 0;
        readonly string[] uriSources = {
            "anim-1.png",
            "anim-2.png", "anim-3.png", "anim-4.png",
            "anim-5.png", "anim-6.png"
        };

        public MainWindow()
        {
            InitializeComponent();

            numberFrames = uriSources.Length;

            Animation();
        }

        private void Animation()
        {
            ObjectAnimationUsingKeyFrames objectAnimation = new()
            {
                Duration = new Duration(TimeSpan.FromSeconds(1.2)),
                RepeatBehavior = RepeatBehavior.Forever
            };

            for (int i = 0; i < numberFrames; i++)
            {
                double quota = (double)i / numberFrames;

                objectAnimation.KeyFrames.Add(
                    new DiscreteObjectKeyFrame()
                    {
                        Value = new BitmapImage(new Uri(uriSources[i], UriKind.Relative)),
                        KeyTime = /*KeyTime.Paced */ KeyTime.FromPercent(quota)
                    }
                );
            }

            System.Windows.Controls.Image image = new()
            {
                Margin = new Thickness(0, 0, 0, 0)
            };
            mainGrid.Children.Add(image);
            image.BeginAnimation(System.Windows.Controls.Image.SourceProperty, objectAnimation);
        }


        bool _canMove = false;
        Point _offsetPoint = new(0, 0);
        private void Window_MouseDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            _canMove = true;
            _offsetPoint = e.MouseDevice.GetPosition(this);
            e.MouseDevice.Capture(this);
        }

        private void Window_MouseMove(object sender, System.Windows.Input.MouseEventArgs e)
        {
            if (_canMove == true)
            {
                Point p = e.MouseDevice.GetPosition(this);
                this.Left = PointToScreen(p).X - _offsetPoint.X;
                this.Top = PointToScreen(p).Y - _offsetPoint.Y;
            }
        }

        private void Window_MouseUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            _canMove = false;
            e.MouseDevice.Capture(null);
        }
    }
}
